% Run model for calculation of r.h.s. of chemostat equations
%
% requires: 
% Implementation: Sven Dietz and Julia Slipantschuk 
% 27.10.2008
% Function:  for model 2-step cascade
function varargout = chemo2(t,y,flag,para)
%Input: t = timestep
%       y = concentration of mutants and substrat
%       para(:,1) = growth rates of mutants
%       para(:,2) = parameters [Ks,Sf,D,Y]
switch flag
  case ''
  
% parameter values    
n = length(y)-1; % number of competitors
UM = para(1:n,1); % growth rates of n competitors
KS = para(1,2);
SF = para(2,2);
D = para(3,2);
Y = para(4,2);
S = y(end); % nutrient(Thy) concentration

    
%%% IMPLEMENT THE MODEL HERE %%%

    C = -D + S/(KS+S) * UM;
    F = S/(Y*(KS+S))* dot(UM,y(1:n));
    
    % construct the matrix such that dy(1:n) = A*dy(1:n)
    i= [1:1:n]';
    j= [1:1:n]';
    v = C;%*ones(n,1);
    A = sparse(i,j,v);
    
    % perform simulation
    %1). dy = Ay
    dy = zeros(n+1,1);
    dy(1:n) = A * y(1:n);
    % 2). evolve nutrient concentration
    dy(n+1)= D * (SF-S) - F;

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
   varargout{1} = dy(:);
      
  case 'init'

    y0 = y;
    
  otherwise
    error(['Unknown flag ''' flag '''.']);

end

return
