% Framework 
%
% requires: 
%   - toolbox: Bioinformatic Toolbox, Cobratoolbox
%   - data: gene data of e.coli, GenomeScale-model
%   - files: chemo2.m, sceI_chemo2.m (included in this package),
%           extractGenesInfoFromGenomeAnnotation.m
%           createAtomicKnockoutStruct.m
%           simGeneDeletionFromAtomicKnockoutsList.m,
%           (the latter found in Image:ETHZ-iGEM2008-GenomeScaleModel.zip)
% Implementation: Sven Dietz and Julia Slipantschuk 
% 29.10.2008


close all

% GenomeScale Model initialization
initCobraToolbox;
m = load('modelKnokoutRichMedium.mat')
model = m.modelKnokoutRichMedium;
model.lb(977)=-0.016
data = load('ecoli.mat');
genomeData = data.data;
[name, pattern, len, ncuts,blunt,c1,c2,c3,c4] = readrebase;
geneInfo=extractGenesInfoFromGenomeAnnotation( genomeData );
i=593;
atomKnockOutStruct=createAtomicKnockoutStruct(genomeData,geneInfo,name{i},pattern{i});

N = 5; % number of pulses
int = 100; % interval of pulses
s = optimizeCbModel(model,'max');
S0 = 8; %substrate initital concnetration
% WT parameters
WT.growth_rate = s.f;
WT.parent = 0;
WT.model = model;
WT.initConcentration = 8;
Mutants = [WT];

y0 = [WT.initConcentration S0]'
UM = [WT.growth_rate];
size(UM)

%% Simulation of WT
tstart = 0;
[y0] = scel_chemo2(1,UM,y0,tstart);
S0 = y0(end);
tstart = tstart + int;

%% Simulation of Cycle
k=1; 
index = 2;
while(k<N)
    for i = 2^(k-1) : 2^k - 1
        for j = 1 : 2
            %Make knockout and calculate growth rate from genome-scale model
            GR = 0;
            while(GR == 0) % consider only these with growth rate different to 0
                [grAtomKnockouts,genesAtomKnocouts,genomeSizeAtomKnockouts,...
                    numOfGenesDelModel,numOfGenesDelGenome,isVital,wt, modelMod] = ...
                    simGeneDeletionFromAtomicKnockoutsList...
                    (genomeData, Mutants(i).model,atomKnockOutStruct, 1, 1);
                GR = grAtomKnockouts;
                if(GR ~= 0)
                    % generate mutant data
                    mutant.growth_rate = grAtomKnockouts;
                    mutant.parent = i;
                    mutant.model = modelMod;
                    mutant.initConcentration = y0(i);
                    % add mutant to a vector
                    Mutants = [Mutants mutant];
                    % update UM(growh rate vector)
                    UM(index) = mutant.growth_rate;
                    % update initial concentration vector
                    y0(index) = mutant.initConcentration;
                    % increase index of arrays (UM, y0)
                    index = index + 1;
                end
            end
        end
    end
% run growth simulation in chemostat
%[y0;S0]
[y0] = scel_chemo2(index-1,UM,[y0;S0],tstart);
S0=y0(end);
% go to next mutatns generation
tstart = tstart + int;
k = k+1;
end





