% Run model for chemostat selection
%
% requires: chemo2.m 
% Implementation: Sven Dietz and Julia Slipantschuk 
% 27.10.2008

function[y0_new] = scel_chemo2(n,UM,y0,tstart)
% Input: 
%    n:     number of competitors
%   UM:     column vector of length(n) with growth rates of competitors
%   y0:     column vector of length(n+1) with initial concentrations of
%           competititor and initial substrate concentration
%   tstart: initial starting time (in h) of simulation
%Output:
%   y0_new: column vector of length(n+1) with initial concentrations of
%   competitors and substrate after the (growth simulation and consecutive pulse) 

%UM = [0.3 0.2 0.09]'; % growth rates of n competitors

%Internal parameters
% para(:,1)  n UM parameter for n coefficients
% para(1:4,2)  parameters [KS,SF,D,Y]
%           where KS = , SF = feed concentration, 
%           S = substrate concentration
if(n<4)
    para = zeros(4,2);
else
    para = zeros(n,2);
end

para(1:n,1)=UM;
para(1:4,2)=[0.1 10 0.55 157]

% integration parameters
pulse = 0.1;
tfinal  = 100;%1200;         % final simulation time [min]
tstep   = 1;           % time step 
MaxAbsT = 1.0;         % maximal step size;

opt = odeset('RelTol',1e-1,'AbsTol',1e-2);


% define parameter vector

y0(1:end-1)=y0(1:end-1)*pulse;
[t,y] = ode15s('chemo2',[tstart:tstep:tfinal+tstart],y0,opt,para);
    y0_new = y(end,1:end)';

    
% plot results
figure(1);
plot(tstart*ones(1,30),linspace(0,700,30),'.k');
hold on;
title('Growth Simulation of E. coli mutants with reduced genome','FontSize',14);
xlabel('Time (h)','FontSize',14);
ylabel('Biomass in g/m^3','FontSize',14);

y_withoutSubstrat = y(:,1:end-1);
ind1 = find(y_withoutSubstrat(1,:)>0.05);
if(length(ind1)~=0)
y_withoutSubstrat = y_withoutSubstrat(:,ind1);
end

%pause;
for k=1:1:tfinal
    plot(t(1:k),y_withoutSubstrat(1:k,:));

    drawnow;
end
hold on
legend('pulse');
    hold on;
